# URBANITE Storage Component 

This component sets up and provides access to the common data and the database.

## Database service connection

Storage component provides the database other components use.
The component sets up the database and provides access to database for other components.
Relevant environment variables:

- `spring.datasource.url`
  URL to storage component's database, including port and database name
- `spring.datasource.username`
  Storage component's database username
- `spring.datasource.password`
  Storage component's database password

## Common data folder

URBANITE Components TS, DSS, and Storage share a common data folder.
The path to the data folder's initial contents is defined in environment variable `storage.host_data_dir`.

### `storage.host_data_dir` structure

Before running, populate the directory with data, available here:
[https://portal.ijs.si/nextcloud/s/m8zkQGAwGipS329](Storage component data)

This server has access to the URBANITE Storage component's shared data folder. 
The structure is as follows:

- `data`
  - `<city_id>`
    - `before_simulation`
      - population generation input files
      - travel demand input files
      - preprocessing files (for calibration)
    - `original_input` - predefined scenarios and all their inputs
      - `networks`
        - `<net_id>` - predefined and user generated network go here
          - `network.xml`
          - `plans` - predefined and user generated plans go here since they are dependent on the network
            - `<plan_id>`
              - `plans.xml`
      - `vehicles.xml` - predefined
      - `config.xml` - original config that is copied to simulation folders
    - `simulations`
      - `<simulation_id>` - created when user creates simulation
        - `network.xml`
        - `vehicles.xml`
        - `plans.xml`
        - `config.xml`
        - `results`
          - `<datetime>` - create when user runs the simulation

## API

- POST `/dss/evaluated`
  Exposes API for retrieving DEXi evaluated KPIs for simulations.
  _request_ `{ ids: [1, ]}`
  _returns_ `{ 1: { kpis }, }`
- POST `/dss/kpis`
  Exposes API for retrieving calculated KPIs for simulations.
  _body_ `{ ids: [1, ]}`
  _returns_ `{ 1: { evaluated kpis }, }`

  _checks if writing to common data access works_

- GET `/test/make_file`
  Creates a test file. 
  Storage can read from it.
  Available on `${storage.url}:${storage.port}/test/read_file`
- GET `/test/change_file`
  Adds content to a test file.
  Storage component can read from it.
  Available on `${storage.url}:${storage.port}/test/read_file`
- GET `/test/show_db`
  Retutrns a dscription of the content of the database.

## User actions

- page create simulation - **WIP**
  1. create/choose network on UUI
  2. create/choose plans for selected network on UUI
  3. run simulation
- page results - **WIP**
  1. list simulations
  2. select simulation and visualize results
